@@ -338,7 +338,7 @@ def query_and_return(project_id, table_id, query, legacy=False):
     return response
 
 
-def get_rows(project_id, dataset_id, table_name, max_results=100000):
+def get_rows(project_id, dataset_id, table_name, max_results=None):
     """Iterate over the specified bigquery table, returning a dict for
     each row of data.
 
